<?php

namespace Aldi\EPA\Policies;

use Litepie\User\Contracts\UserPolicy;
use Aldi\EPA\Models\TabelM;

class TabelMPolicy
{

    /**
     * Determine if the given user can view the tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function view(UserPolicy $user, TabelM $tabel_m)
    {
        if ($user->canDo('e_p_a.tabel_m.view') && $user->isAdmin()) {
            return true;
        }

        return $tabel_m->user_id == user_id() && $tabel_m->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('e_p_a.tabel_m.create');
    }

    /**
     * Determine if the given user can update the given tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function update(UserPolicy $user, TabelM $tabel_m)
    {
        if ($user->canDo('e_p_a.tabel_m.edit') && $user->isAdmin()) {
            return true;
        }

        return $tabel_m->user_id == user_id() && $tabel_m->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TabelM $tabel_m)
    {
        return $tabel_m->user_id == user_id() && $tabel_m->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TabelM $tabel_m)
    {
        if ($user->canDo('e_p_a.tabel_m.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tabel_m.
     *
     * @param UserPolicy $user
     * @param TabelM $tabel_m
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TabelM $tabel_m)
    {
        if ($user->canDo('e_p_a.tabel_m.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
