<?php

namespace Aldi\EPA\Providers;

use Illuminate\Support\ServiceProvider;

class EPAServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'e_p_a');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'e_p_a');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEPA();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEPA()
    {
        $this->app->bind('e_p_a', function($app) {
            return new EPA($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('EPA', 'Lavalite\EPA\Facades\EPA');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('aldi.e_p_a', function ($app) {
            return $this->app->make('Aldi\EPA\EPA');
        });

                // Bind TabelM to repository
        $this->app->bind(
            'Aldi\EPA\Interfaces\TabelMRepositoryInterface',
            \Aldi\EPA\Repositories\Eloquent\TabelMRepository::class
        );

        $this->app->register(\Aldi\EPA\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Aldi\EPA\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and e_p_a's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/e_p_a.php', 'e_p_a'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEPA::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['aldi.e_p_a'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('aldi/e_p_a.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/e_p_a')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/e_p_a')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
